Calculates time-dependent index when nodes weights or barriers passability are changing - not for exporting
inner_t_index_calculation(
graph,
barriers_metadata,
id_barrier,
year,
pass_u,
pass_d,
weights_metadata,
weight,
nodes_id,
parallel,
ncores,
index_type,
index_mode,
c_ij_flag,
B_ij_flag,
dir_fragmentation_type,
pass_confluence,
field_B,
dir_distance_type,
disp_type,
param_u,
param_d,
param,
param_l
)a data.frame with a 'year' field and related connectity index.
If index_type = "reach", the data.frame is organized by 'year' and 'name'.
an object of class igraph. Can be both directed or undirected.
data.frame that must contain a column having the same name as the 'id_barrier' attribute of the graph,
and two columns with the corresponding upstream and downstream improved passabilities (see pass_u and pass_d), and a column with the year
passability was changed. This data frame can be obtained from easily-formatted data with the function t_passability_sequencer.
graph edges numeric attribute used to label barriers. Default is "id_barrier". It should be present in the 'barriers metadata' input as well.
field of the 'barriers metadata' where temporal information on the changes in passabiity is stored.
check index_calculation function.
check index_calculation function.
data.frame that must contain a column having the same name as the 'nodes_id' attribute of the graph,
a column with he corresponding weight information (see 'weight' parameter), and a column with the year
weight was changed. This data frame can be obtained from easily-formatted data with the function t_weight_sequencer.
param weight graph vertex attribute used to assign weights to the reaches (nodes). Default is "length".
graph vertex attribute used to univoquely label reaches (nodes). Default is "name".
logical value to flag if parallel option is to be used.
define how many cores are used in parallel processing. Active only when parallel = TRUE
check index_calculation function.
check index_calculation function.
check index_calculation function.
check index_calculation function.
check index_calculation function.
check index_calculation function.
check index_calculation function.
check index_calculation function.
check index_calculation function.
check index_calculation function.
check index_calculation function.
check index_calculation function.